#!/usr/bin/env python

##*****************************************************************************
##
## File: createNode.py
##
## Copyright 2016 Autodesk, Inc.  All rights reserved.
## Use of this software is subject to the terms of the Autodesk license
## agreement provided at the time of installation or download, or which
## otherwise accompanies this software in either electronic or hard copy form.
##
##*****************************************************************************

"""
Wiretap SDK sample python program to create a library node or any other
generic node.
"""

from __future__ import print_function
from __future__ import absolute_import

import sys
import getopt

from adsk.libwiretapPythonClientAPI import WireTapClient
from adsk.libwiretapPythonClientAPI import WireTapServerHandle
from adsk.libwiretapPythonClientAPI import WireTapNodeHandle

## Please see the Wiretap Developer's Guide for an explanation of the
## Wiretap IFFFS server nodes hierarchy.

class WireTapException(Exception):
    pass

def main(argv):

    # check the command line options for correctness
    try:
        opts, _ = getopt.getopt(argv, "h:n:t:d:")
    except getopt.GetoptError:
        print("Usage:\n" \
              "-h <hostname>\n" \
              "-n <parent node id>\n"\
              "-t <node type>\n"\
              "-d <node name>")
        sys.exit(2)

    # default host name and node ID
    host_name = "localhost"
    node_id = ""
    node_type = "LIBRARY"
    node_name = "New Node"

    # parse command line option to set specified host name
    # and node ID
    for opt, arg in opts:
        if opt == '-h':
            host_name = arg
        elif opt == '-n':
            node_id = arg
        elif opt == '-t':
            node_type = arg
        elif opt == '-d':
            node_name = arg

    # Initialize the Wiretap Client API.
    #
    wiretap_client = WireTapClient()
    if not wiretap_client.init():
        raise WireTapException("Unable to initialize Wiretap client API.")

    create_node(host_name, node_id, node_name, node_type)

def create_node(host_name, node_id, node_name, node_type):

    # Instantiate a server handle
    #
    server_handle = WireTapServerHandle(host_name)

    # Instantiate the clip node handle for the given server and node ID.
    #
    parent_node_handle = WireTapNodeHandle(server_handle, node_id)

    # Create a new node of type 'node_type'. Each Wiretap server defines a set of
    # node types (specified as string constants).
    #
    new_node_handle = WireTapNodeHandle()
    if not parent_node_handle.createNode(
            node_name,
            node_type,
            new_node_handle):
        raise WireTapException("Unable to create node type %s: %s." % \
                               (node_type, parent_node_handle.lastError()))
    print("New node created '%s'" % new_node_handle.getNodeId().id())

if __name__ == '__main__':
    main(sys.argv[1:])
