#!/usr/bin/env python

#
# Wiretap SDK tool for obtaining the display name of a node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
    WireTapStr
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "[-h <hostname>]")

def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the node and get its display name.
        #
        node = WireTapNodeHandle(server, nodeId)
        name = WireTapStr()
        if not node.getDisplayName(name):
            raise Exception("Unable to retrieve display name: %s" % node.lastError())

        print(name.c_str())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None


if __name__ == '__main__':
    main()
