#! /usr/bin/env python

# Wiretap SDK tool for renaming a node.

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle
)

def printUsage():
    print("Usage:\n"
          "-n <node Id>\n"
          "-d <new display name>\n"
          "[-h <host name or IP address> (default = localhost)]\n")

def main():

    # Check the command line options for correctness.
    #
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:d:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""
    displayName = ""

    # Parse command line and set variables just declared
    #
    for opt, arg in opts:
        if opt == '-h':
            hostName = arg
        elif opt == '-n':
            nodeId = arg
        elif opt == '-d':
            displayName = arg

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    if displayName == "":
        print("New Display Name not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Destroy the node with the specified ID.
        #
        node = WireTapNodeHandle(server, nodeId)
        if not node.renameNode(displayName):
            raise Exception("Cannot rename node: %s " % node.lastError())
        print("Renamed node '%s'." % node.getNodeId().id())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None

if __name__ == '__main__':
    main()
